@@ -1521,6 +1521,7 @@ gtkam_tree_save (GtkamTree *tree)
 	n = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (tree->priv->store),
 					    NULL);
 	for (i = 0; i < n; i++) {
+		char *xpath;
 		gtk_tree_model_iter_nth_child (
 					GTK_TREE_MODEL (tree->priv->store),
 					&child, NULL, i);
@@ -1528,6 +1529,11 @@ gtkam_tree_save (GtkamTree *tree)
 
 		gp_camera_get_abilities (camera->camera, &a);
 		gp_camera_get_port_info (camera->camera, &info);
+#if 0
+		gp_port_info_get_path (info, &xpath);
+#else
+		xpath = info.path;
+#endif
 		speed = gp_camera_get_port_speed (camera->camera);
 
 		ms = g_strdup_printf ("model-%i", i + 1);
@@ -1535,7 +1541,7 @@ gtkam_tree_save (GtkamTree *tree)
 		g_free (ms);
 
 		ms = g_strdup_printf ("port-%i", i + 1);
-		gp_setting_set ("gtkam", ms, info.path);
+		gp_setting_set ("gtkam", ms, xpath);
 		g_free (ms);
 
 		ms = g_strdup_printf ("multi-%i", i + 1);
